@@ -15,9 +15,7 @@ class Command(BaseCommand):
         return FormSubmission.objects.filter(submit_time__lt=date)
 
     def handle(self, *args, **options):
-        keep_from_date = datetime.today().date() - timedelta(
-            days=options["days_to_keep"]
-        )
+        keep_from_date = datetime.today().date() - timedelta(days=options["days_to_keep"])
 
         queryset = self.get_queryset(keep_from_date)
 
