@@ -4,14 +4,14 @@ from django.conf import settings
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 from wagtail import VERSION as WAGTAIL_VERSION
-from wagtail.admin.edit_handlers import (
+from wagtail.admin.panels import (
     FieldPanel,
     MultiFieldPanel,
     ObjectList,
     PageChooserPanel,
     TabbedInterface,
 )
-from wagtail.core.models import Site
+from wagtail.models import Site
 
 from wagtailstreamforms import hooks
 from wagtailstreamforms.conf import get_setting
@@ -43,7 +43,7 @@ class AbstractForm(models.Model):
     template_name = models.CharField(
         _("Template"), max_length=255, choices=get_setting("FORM_TEMPLATES")
     )
-    fields = FormFieldsStreamField([], verbose_name=_("Fields"))
+    fields = FormFieldsStreamField([], use_json_field=True, verbose_name=_("Fields"))
     submit_button_text = models.CharField(
         _("Submit button text"), max_length=100, default="Submit"
     )
@@ -59,9 +59,7 @@ class AbstractForm(models.Model):
         _("Error message"),
         blank=True,
         max_length=255,
-        help_text=_(
-            "An optional error message to show when the form has validation errors"
-        ),
+        help_text=_("An optional error message to show when the form has validation errors"),
     )
     post_redirect_page = models.ForeignKey(
         "wagtailcore.Page",
@@ -72,9 +70,7 @@ class AbstractForm(models.Model):
         related_name="+",
         help_text=_("The page to redirect to after a successful submission"),
     )
-    process_form_submission_hooks = HookSelectField(
-        verbose_name=_("Submission hooks"), blank=True
-    )
+    process_form_submission_hooks = HookSelectField(verbose_name=_("Submission hooks"), blank=True)
 
     objects = FormQuerySet.as_manager()
 
