@@ -5,17 +5,17 @@ from django.template.response import TemplateResponse
 from django.urls import include, path, reverse
 from django.utils.translation import gettext_lazy as _
 from generic_chooser.views import ModelChooserViewSet
-from generic_chooser.widgets import AdminChooser
+from wagtail import hooks
 from wagtail.admin import messages as wagtail_messages
-from wagtail.contrib.modeladmin.helpers import AdminURLHelper, ButtonHelper
-from wagtail.contrib.modeladmin.options import ModelAdmin, modeladmin_register
-from wagtail.contrib.modeladmin.views import (
+from wagtail.admin.widgets import AdminPageChooser
+from wagtail_modeladmin.helpers import AdminURLHelper, ButtonHelper
+from wagtail_modeladmin.options import ModelAdmin, modeladmin_register
+from wagtail_modeladmin.views import (
     CreateView,
     DeleteView,
     EditView,
     InspectView,
 )
-from wagtail.core import hooks
 
 from wagtailstreamforms import hooks as form_hooks
 from wagtailstreamforms.conf import get_setting
@@ -29,9 +29,7 @@ SettingsModel = get_advanced_settings_model()
 class FormURLHelper(AdminURLHelper):
     def get_action_url(self, action, *args, **kwargs):
         if action in ["advanced", "copy", "submissions"]:
-            return reverse(
-                "wagtailstreamforms:streamforms_%s" % action, args=args, kwargs=kwargs
-            )
+            return reverse("wagtailstreamforms:streamforms_%s" % action, args=args, kwargs=kwargs)
 
         return super().get_action_url(action, *args, **kwargs)
 
@@ -48,21 +46,15 @@ class FormButtonHelper(ButtonHelper):
 
         return button
 
-    def get_buttons_for_obj(
-        self, obj, exclude=None, classnames_add=None, classnames_exclude=None
-    ):
-        buttons = super().get_buttons_for_obj(
-            obj, exclude, classnames_add, classnames_exclude
-        )
+    def get_buttons_for_obj(self, obj, exclude=None, classnames_add=None, classnames_exclude=None):
+        buttons = super().get_buttons_for_obj(obj, exclude, classnames_add, classnames_exclude)
         pk = getattr(obj, self.opts.pk.attname)
         ph = self.permission_helper
         usr = self.request.user
 
         # if there is a form settings model defined
         # users that either create or edit forms should be able edit advanced settings
-        if SettingsModel and (
-            ph.user_can_create(usr) or ph.user_can_edit_obj(usr, obj)
-        ):
+        if SettingsModel and (ph.user_can_create(usr) or ph.user_can_edit_obj(usr, obj)):
             buttons.append(
                 self.button(
                     pk,
@@ -152,6 +144,7 @@ class FormModelAdmin(ModelAdmin):
     edit_view_class = EditFormView
     delete_view_class = DeleteFormView
     url_helper_class = FormURLHelper
+    index_template_name = "modeladmin/index.html"
 
     def get_queryset(self, request):
         qs = super().get_queryset(request)
@@ -173,11 +166,7 @@ class FormModelAdmin(ModelAdmin):
 
     def latest_submission(self, obj):
         submission_class = obj.get_submission_class()
-        return (
-            submission_class._default_manager.filter(form=obj)
-            .latest("submit_time")
-            .submit_time
-        )
+        return submission_class._default_manager.filter(form=obj).latest("submit_time").submit_time
 
     latest_submission.short_description = _("Latest submission")
 
@@ -207,9 +196,7 @@ def process_form(page, request, *args, **kwargs):
         form_def = get_form_instance_from_request(request)
 
         if form_def:
-            form = form_def.get_form(
-                request.POST, request.FILES, page=page, user=request.user
-            )
+            form = form_def.get_form(request.POST, request.FILES, page=page, user=request.user)
             context = page.get_context(request, *args, **kwargs)
 
             if form.is_valid():
@@ -218,9 +205,7 @@ def process_form(page, request, *args, **kwargs):
 
                 # create success message
                 if form_def.success_message:
-                    messages.success(
-                        request, form_def.success_message, fail_silently=True
-                    )
+                    messages.success(request, form_def.success_message, fail_silently=True)
 
                 # redirect to the page defined in the form
                 # or the current page as a fallback - this will avoid refreshing
@@ -233,9 +218,7 @@ def process_form(page, request, *args, **kwargs):
                 # update the context with the invalid form and serve the page
                 context.update(
                     {
-                        "invalid_stream_form_reference": form.data.get(
-                            "form_reference"
-                        ),
+                        "invalid_stream_form_reference": form.data.get("form_reference"),
                         "invalid_stream_form": form,
                     }
                 )
@@ -256,7 +239,7 @@ class WagtailStreamFormsChooserViewSet(ModelChooserViewSet):
     per_page = 10
 
 
-class WagtailStreamFormsChooser(AdminChooser):
+class WagtailStreamFormsChooser(AdminPageChooser):
     choose_one_text = _("Choose a form")
     choose_another_text = _("Choose another form")
     link_to_chosen_text = _("Edit this form")
